@@ -8,9 +8,7 @@
 #' @importFrom glue glue
 #' @importFrom xml2 read_html
 #' @importFrom dplyr  %>% filter pull slice
-#' @importFrom tibble tibble
 #' @importFrom rvest html_nodes html_attr html_text
-#' @importFrom stringr str_trim str_remove
 #' @importFrom purrr map_dfr
 #' @importFrom rlang .data
 #'
@@ -18,11 +16,12 @@
 scrape_abs_catalogues <- function() {
 
   # scrape the main page
-  abs_stats_page <- xml2::read_html("https://www.abs.gov.au/statistics")
+  abs_stats_page <- xml2::read_html("https://www.abs.gov.au/statistics",
+                                    user_agent = readabs_user_agent)
 
-  main_page_data <- tibble::tibble(
-    heading = abs_stats_page %>% rvest::html_nodes(".field--type-ds h3") %>% rvest::html_text() %>% stringr::str_trim(),
-    url_suffix = abs_stats_page %>% rvest::html_nodes(".card") %>% rvest::html_attr("href") %>% stringr::str_trim()
+  main_page_data <- dplyr::tibble(
+    heading = abs_stats_page %>% rvest::html_nodes(".field--type-ds h3") %>% rvest::html_text() %>% stringi::stri_trim_both(),
+    url_suffix = abs_stats_page %>% rvest::html_nodes(".card") %>% rvest::html_attr("href") %>% stringi::stri_trim_both()
   )
 
   # scrape each page
@@ -31,15 +30,16 @@ scrape_abs_catalogues <- function() {
     main_page_heading <- main_page_data$heading[main_page_data$url_suffix == sub_page_url_suffix]
 
 
-    sub_page <- xml2::read_html(glue::glue("https://www.abs.gov.au{sub_page_url_suffix}"))
+    sub_page <- xml2::read_html(glue::glue("https://www.abs.gov.au{sub_page_url_suffix}"),
+                                user_agent = readabs_user_agent)
 
-    sub_page_data <- tibble::tibble(
+    sub_page_data <- dplyr::tibble(
       heading = main_page_heading,
-      sub_heading = sub_page %>% rvest::html_nodes(".abs-layout-title") %>% rvest::html_text() %>% str_trim(),
+      sub_heading = sub_page %>% rvest::html_nodes(".abs-layout-title") %>% rvest::html_text() %>% stringi::stri_trim_both(),
       catalogue = sub_page %>% rvest::html_nodes("#content .card") %>% rvest::html_attr("href") %>%
-        stringr::str_remove(sub_page_url_suffix) %>%
-        stringr::str_remove("/[^/]*$") %>%
-        stringr::str_remove("/"),
+        stringi::stri_replace_all_fixed(sub_page_url_suffix, "") %>%
+        stringi::stri_replace_all_regex("/[^/]*$", "") %>%
+        stringi::stri_replace_all_fixed("/", ""),
       url = glue::glue("https://www.abs.gov.au{sub_page_url_suffix}/{catalogue}/latest-release")
     )
   }
